# Changelog

This is the changelog for Tarmac.

## 0.1.3

## Changed

- Add build artifacts to release assets

## 0.1.2

### Fixed

- Improve release CI workflow

## 0.1.1

### Added

- Add CI and release workflows.
- Add `--base-path` argument to  `tarmac` command

## 0.1.0

Initial release.
